#!/usr/bin/env bash
###
 # Generates a set of "test" backup files in the provided directory, going back slightly more than two full years.
 # For use in combination with manage_backups script.
 #
 #
 # Required Args:
 #  * Directory to Generate to
 #
 # Optional Flags:
 #  * Force - Force script to execute without confirmation of provided args.
 #      * Accepted Flags: f / force
 #
 #
 # https://git.brandon-rodriguez.com/scripts/bash/server_management
 # Version 1.0
 ##


# Define possible flag values for script.
possible_flags=("-f" "-force")


# Import utils script.
. $(dirname ${0})/../utils.sh


# Stop on error.
set -e


###
 # Script entry point.
 ##
function main () {

    # Check for args.
    if [[ ${#args[@]} != 1 ]]
    then
        if [[ ${#args[@]} < 1 ]]
        then
            echo -e "${text_red}Missing \"directory\" arg. This is where test files willl generate to.${text_reset}"
            exit 0
        else
            echo -e "${text_red}Script only takes \"directory\" arg. This is where test files willl generate to.${text_reset}"
        fi
    fi

    # Check that location exists.
    get_absolute_path "${args[0]}"
    local directory="${return_value}"
    if [[ ! -d ${directory} ]]
    then
        echo -e "${text_red}Provided location is not a folder, or does not exist.${text_reset}"
        echo -e "${text_red}Please verify the location exists, and that the location points to a folder, not a file.${text_reset}"
        exit 0
    fi

    # Confirm directory if force flag not provided.
    if [[ ! ${flags[@]} =~ "f" && ! ${flags[@]} =~ "force" ]]
    then
        echo ""
        echo "Provided directory of \"${directory}\"."
        echo ""
        get_user_confirmation "Is this correct?"
        if [[ ${return_value} == false ]]
        then
            echo -e "${text_orange}Please correct directory location and rerun script.${text_reset}"
            exit 0
        fi
    fi

    # Generate files.
    for index in {0..750}
    do
        local date_value=$(date -d "$(date +%Y-%m-%d) -${index} day" +%Y-%m-%d)
        touch "${directory}/test_backup__${date_value}.sql.gz"
    done

}


main
